Validator<T> typedef
Validator<T> =
String? Function(T value)
A synchronous validator returning an error message, or null when valid.
Implementation
typedef Validator<T> = String? Function(T value);
A synchronous validator returning an error message, or null when valid.
typedef Validator<T> = String? Function(T value);